@@ -35,7 +35,7 @@ class Locale(object):
     langData = OrderedDict([
         ('be_BY', {
             'name': 'Беларуская (Беларусь)',
-            'locale': 'be_BY.UTF-8',
+            'locale': 'be_BY.utf8',
             'keymap': 'by',
             'timezone': 'Europe/Minsk',
             'dumpkeys_charset': 'koi8-u',
@@ -45,7 +45,7 @@ class Locale(object):
         }),
         ('bg_BG', {
             'name': 'Български (България)',
-            'locale': 'bg_BG.UTF-8',
+            'locale': 'bg_BG.utf8',
             'keymap': 'bg_bds-utf8',
             'dumpkeys_charset': '',
             'timezone': 'Europe/Sofia',
@@ -55,7 +55,7 @@ class Locale(object):
         }),
         ('bs_BA', {
             'name': 'Bosanski (Bosna i Hercegovina)',
-            'locale': 'bs_BA.UTF-8',
+            'locale': 'bs_BA.utf8',
             'keymap': 'slovene',
             'timezone': 'Europe/Sarajevo',
             'dumpkeys_charset': '',
@@ -65,7 +65,7 @@ class Locale(object):
         }),
         ('cs_CZ', {
             'name': 'Čeština (Česká republika)',
-            'locale': 'cs_CZ.UTF-8',
+            'locale': 'cs_CZ.utf8',
             'keymap': 'cz',
             'timezone': 'Europe/Prague',
             'dumpkeys_charset': '',
@@ -75,7 +75,7 @@ class Locale(object):
         }),
         ('da_DK', {
             'name': 'Dansk (Danmark)',
-            'locale': 'da_DK.UTF-8',
+            'locale': 'da_DK.utf8',
             'keymap': 'dk-latin1',
             'timezone': 'Europe/Copenhagen',
             'dumpkeys_charset': '',
@@ -85,7 +85,7 @@ class Locale(object):
         }),
         ('de_DE', {
             'name': 'Deutsch (Deutschland)',
-            'locale': 'de_DE.UTF-8',
+            'locale': 'de_DE.utf8',
             'keymap': 'de-latin1',
             'timezone': 'Europe/Berlin',
             'dumpkeys_charset': '',
@@ -95,7 +95,7 @@ class Locale(object):
         }),
         ('en_AU', {
             'name': 'English (Australia)',
-            'locale': 'en_AU.UTF-8',
+            'locale': 'en_AU.utf8',
             'keymap': 'us',
             'timezone': 'Australia/Canberra',
             'dumpkeys_charset': '',
@@ -105,7 +105,7 @@ class Locale(object):
         }),
         ('en_GB', {
             'name': 'English (United Kingdom)',
-            'locale': 'en_GB.UTF-8',
+            'locale': 'en_GB.utf8',
             'keymap': 'uk',
             'timezone': 'Europe/London',
             'dumpkeys_charset': '',
@@ -115,7 +115,7 @@ class Locale(object):
         }),
         ('en_US', {
             'name': 'English (United States)',
-            'locale': 'en_US.UTF-8',
+            'locale': 'en_US.utf8',
             'keymap': 'us',
             'timezone': 'America/New_York',
             'dumpkeys_charset': '',
@@ -125,7 +125,7 @@ class Locale(object):
         }),
         ('es_ES', {
             'name': 'Español (España)',
-            'locale': 'es_ES.UTF-8',
+            'locale': 'es_ES.utf8',
             'keymap': 'es euro2',
             'timezone': 'Europe/Madrid',
             'dumpkeys_charset': '',
@@ -135,7 +135,7 @@ class Locale(object):
         }),
         ('es_UY', {
             'name': 'Español (Uruguay)',
-            'locale': 'es_UY.UTF-8',
+            'locale': 'es_UY.utf8',
             'keymap': 'la-latin1',
             'timezone': 'America/Montevideo',
             'dumpkeys_charset': '',
@@ -145,7 +145,7 @@ class Locale(object):
         }),
         ('es_VE', {
             'name': 'Español (Venezuela)',
-            'locale': 'es_VE.UTF-8',
+            'locale': 'es_VE.utf8',
             'keymap': 'la-latin1',
             'timezone': 'America/Caracas',
             'dumpkeys_charset': '',
@@ -155,7 +155,7 @@ class Locale(object):
         }),
         ('et_EE', {
             'name': 'Eesti (Eesti)',
-            'locale': 'et_EE.UTF-8',
+            'locale': 'et_EE.utf8',
             'keymap': 'et',
             'timezone': 'Europe/Tallinn',
             'dumpkeys_charset': '',
@@ -165,7 +165,7 @@ class Locale(object):
         }),
         ('fr_BE', {
             'name': 'Français (Belgique)',
-            'locale': 'fr_BE.UTF-8',
+            'locale': 'fr_BE.utf8',
             'keymap': 'be-latin1',
             'timezone': 'Europe/Brussels',
             'dumpkeys_charset': '',
@@ -175,7 +175,7 @@ class Locale(object):
         }),
         ('fr_CA', {
             'name': 'Français (Canada)',
-            'locale': 'fr_CA.UTF-8',
+            'locale': 'fr_CA.utf8',
             'keymap': 'cf',
             'timezone': 'Canada/Pacific',
             'dumpkeys_charset': '',
@@ -185,7 +185,7 @@ class Locale(object):
         }),
         ('fr_FR', {
             'name': 'Français (France)',
-            'locale': 'fr_FR.UTF-8',
+            'locale': 'fr_FR.utf8',
             'keymap': 'fr-latin9',
             'timezone': 'Europe/Paris',
             'dumpkeys_charset': '',
@@ -195,7 +195,7 @@ class Locale(object):
         }),
         ('hr_HR', {
             'name': 'Hrvatski (Hrvatska)',
-            'locale': 'hr_HR.UTF-8',
+            'locale': 'hr_HR.utf8',
             'keymap': 'croat',
             'timezone': 'Europe/Zagreb',
             'dumpkeys_charset': '',
@@ -205,7 +205,7 @@ class Locale(object):
         }),
         ('is_IS', {
             'name': 'Íslenska (Ísland)',
-            'locale': 'is_IS.UTF-8',
+            'locale': 'is_IS.utf8',
             'keymap': 'is-latin1',
             'timezone': 'Atlantic/Reykjavik',
             'dumpkeys_charset': '',
@@ -215,7 +215,7 @@ class Locale(object):
         }),
         ('it_IT', {
             'name': 'Italiano (Italia)',
-            'locale': 'it_IT.UTF-8',
+            'locale': 'it_IT.utf8',
             'keymap': 'it',
             'dumpkeys_charset': '',
             'timezone': 'Europe/Rome',
@@ -225,7 +225,7 @@ class Locale(object):
         }),
         ('kk_KZ', {
             'name': 'Қазақ тілі (Қазақстан)',
-            'locale': 'kk_KZ.UTF-8',
+            'locale': 'kk_KZ.utf8',
             'keymap': 'kaz_gost-unicode',
             'timezone': 'Asia/Almaty',
             'dumpkeys_charset': '',
@@ -235,7 +235,7 @@ class Locale(object):
         }),
         ('lt_LT', {
             'name': 'Lietuvių (Lietuva)',
-            'locale': 'lt_LT.UTF-8',
+            'locale': 'lt_LT.utf8',
             'keymap': 'lt.baltic',
             'timezone': 'Europe/Vilnius',
             'dumpkeys_charset': '',
@@ -245,7 +245,7 @@ class Locale(object):
         }),
         ('lv_LV', {
             'name': 'Latviešu (Latvija)',
-            'locale': 'lv_LV.UTF-8',
+            'locale': 'lv_LV.utf8',
             'keymap': 'lv',
             'timezone': 'Europe/Riga',
             'dumpkeys_charset': '',
@@ -255,7 +255,7 @@ class Locale(object):
         }),
         ('hu_HU', {
             'name': 'Magyar (Magyarország)',
-            'locale': 'hu_HU.UTF-8',
+            'locale': 'hu_HU.utf8',
             'keymap': 'hu',
             'timezone': 'Europe/Budapest',
             'dumpkeys_charset': '',
@@ -265,7 +265,7 @@ class Locale(object):
         }),
         ('nl_BE', {
             'name': 'Nederlands (België)',
-            'locale': 'nl_BE.UTF-8',
+            'locale': 'nl_BE.utf8',
             'keymap': 'nl',
             'timezone': 'Europe/Brussels',
             'dumpkeys_charset': '',
@@ -275,7 +275,7 @@ class Locale(object):
         }),
         ('nl_NL', {
             'name': 'Nederlands (Nederland)',
-            'locale': 'nl_NL.UTF-8',
+            'locale': 'nl_NL.utf8',
             'keymap': 'nl',
             'timezone': 'Europe/Amsterdam',
             'dumpkeys_charset': '',
@@ -285,7 +285,7 @@ class Locale(object):
         }),
         ('nn_NO', {
             'name': 'Nynorsk (Noreg)',
-            'locale': 'nn_NO.UTF-8',
+            'locale': 'nn_NO.utf8',
             'keymap': 'no-latin1',
             'timezone': 'Europe/Oslo',
             'dumpkeys_charset': '',
@@ -295,7 +295,7 @@ class Locale(object):
         }),
         ('pl_PL', {
             'name': 'Polski (Polska)',
-            'locale': 'pl_PL.UTF-8',
+            'locale': 'pl_PL.utf8',
             'keymap': 'pl',
             'timezone': 'Europe/Warsaw',
             'dumpkeys_charset': '',
@@ -305,7 +305,7 @@ class Locale(object):
         }),
         ('pt_BR', {
             'name': 'Português (Brasil)',
-            'locale': 'pt_BR.UTF-8',
+            'locale': 'pt_BR.utf8',
             'keymap': 'br-abnt2',
             'timezone': 'Brazil/East',
             'dumpkeys_charset': '',
@@ -315,7 +315,7 @@ class Locale(object):
         }),
         ('pt_PT', {
             'name': 'Português (Portugal)',
-            'locale': 'pt_PT.UTF-8@euro',
+            'locale': 'pt_PT.utf8@euro',
             'keymap': 'pt-latin9',
             'dumpkeys_charset': '',
             'timezone': 'Europe/Lisbon',
@@ -325,7 +325,7 @@ class Locale(object):
         }),
         ('ro_RO', {
             'name': 'Română (România)',
-            'locale': 'ro_RO.UTF-8',
+            'locale': 'ro_RO.utf8',
             'keymap': 'ro_win',
             'timezone': 'Europe/Bucharest',
             'dumpkeys_charset': '',
@@ -335,8 +335,8 @@ class Locale(object):
         }),
         ('ru_RU', {
             'name': 'Русский (Россия)',
-            'locale': 'ru_RU.UTF-8',
-            'keymap': '-u ruwin_cplk-UTF-8',
+            'locale': 'ru_RU.utf8',
+            'keymap': '-u ruwin_cplk-utf8',
             'timezone': 'Europe/Moscow',
             'dumpkeys_charset': '',
             'consolefont': 'ter-v14n',
@@ -345,7 +345,7 @@ class Locale(object):
         }),
         ('sk_SK', {
             'name': 'Slovenčina (Slovenská republika)',
-            'locale': 'sk_SK.UTF-8',
+            'locale': 'sk_SK.utf8',
             'keymap': 'sk-qwertz',
             'dumpkeys_charset': '',
             'timezone': 'Europe/Bratislava',
@@ -355,7 +355,7 @@ class Locale(object):
         }),
         ('sl_SI', {
             'name': 'Slovenščina (Slovenija)',
-            'locale': 'sl_SI.UTF-8',
+            'locale': 'sl_SI.utf8',
             'keymap': 'slovene',
             'timezone': 'Europe/Ljubljana',
             'dumpkeys_charset': '',
@@ -365,7 +365,7 @@ class Locale(object):
         }),
         ('sq_AL', {
             'name': 'Shqip (Shqipëria)',
-            'locale': 'sq_AL.UTF-8',
+            'locale': 'sq_AL.utf8',
             'keymap': 'al',
             'timezone': 'Europe/Tirane',
             'dumpkeys_charset': '',
@@ -375,7 +375,7 @@ class Locale(object):
         }),
         ('sr_RS', {
             'name': 'Српски (Србија)',
-            'locale': 'sr_RS.UTF-8',
+            'locale': 'sr_RS.utf8',
             'keymap': 'sr-unicode',
             'timezone': 'Europe/Belgrade',
             'dumpkeys_charset': '',
@@ -385,7 +385,7 @@ class Locale(object):
         }),
         ('fi_FI', {
             'name': 'Suomi (Suomi)',
-            'locale': 'fi_FI.UTF-8',
+            'locale': 'fi_FI.utf8',
             'keymap': 'fi-latin9',
             'timezone': 'Europe/Helsinki',
             'dumpkeys_charset': '',
@@ -395,7 +395,7 @@ class Locale(object):
         }),
         ('sv_SE', {
             'name': 'Svenska (Sverige)',
-            'locale': 'sv_SE.UTF-8',
+            'locale': 'sv_SE.utf8',
             'keymap': 'sv-latin1',
             'timezone': 'Europe/Stockholm',
             'dumpkeys_charset': '',
@@ -405,7 +405,7 @@ class Locale(object):
         }),
         ('uk_UA', {
             'name': 'Українська (Україна)',
-            'locale': 'uk_UA.UTF-8',
+            'locale': 'uk_UA.utf8',
             'keymap': 'ua-utf',
             'timezone': 'Europe/Kiev',
             'dumpkeys_charset': 'koi8-u',
@@ -470,7 +470,7 @@ class VariableOsClockTimezone(ReadonlyVariable):
 
 class VariableOsLocaleLocale(ReadonlyVariable, Locale):
     """
-    Locale (example: ru_RU.UTF-8)
+    Locale (example: ru_RU.utf8)
     """
     env_var = "LANG"
 
